def add(x, y):
    """Add two numbers together.

    Parameters
    ----------
    x : int
        The first number.
    y : int
        The second number.

    Returns
    -------
    z : int
        The first number plus the second number

    Example
    -------
    >>> add(2, 2)
    """
    return x + y


def subtract(x, y):
    """Subtract one number from another.

    Parameters
    ----------
    x : int
        The first number.
    y : int
        The second number.

    Returns
    -------
    z : int
        The first number minus the second number

    Example
    -------
    >>> subtract(2, 1)
    """
    return x - y
